%define module_name paramiko

# disable tests, pytest-relaxed which we don't have and even
# if we would have it, it needs pytests < 3.3
%bcond_with tests

Summary:       SSH2 protocol for Python
Name:          python-%{module_name}
Version:       2.7.2
Release:       %mkrel 1
Url:           https://github.com/paramiko/paramiko/
License:       LGPLv2+
Group:         Development/Python
Source0:       https://pypi.io/packages/source/p/%{module_name}/%{module_name}-%{version}.tar.xz
# Missing from pypi source tarball
Source1:       test_dss.key-cert.pub
Source2:       test_ecdsa_256.key-cert.pub
Source3:       test_ed25519.key-cert.pub
Source4:       test_rsa.key-cert.pub
Patch0:        CVE-2022-24302.patch
BuildArch:     noarch

Provides:      %{module_name} = %{version}-%{release}
Requires:      python-cryptography
Requires:      python-enum34

%global paramiko_desc \
Paramiko (a combination of the esperanto words for "paranoid" and "friend") is\
a module for python 2.3 or greater that implements the SSH2 protocol for secure\
(encrypted and authenticated) connections to remote machines. Unlike SSL (aka\
TLS), the SSH2 protocol does not require heirarchical certificates signed by a\
powerful central authority. You may know SSH2 as the protocol that replaced\
telnet and rsh for secure access to remote shells, but the protocol also\
includes the ability to open arbitrary channels to remote services across an\
encrypted tunnel. (This is how sftp works, for example.)\


%description
%{paramiko_desc}

Python 2 version.


%package -n python3-%{module_name}
Group:         Development/Python
Summary:       SSH2 protocol library for python
BuildRequires:  python3-cryptography
Requires:      python3-cryptography

%description -n python3-%{module_name}
%{paramiko_desc}

Python 3 version.


%prep
%setup -n %{module_name}-%{version}
%apply_patches

# Remove bundled egg-info
rm -rf %{pypi_name}.egg-info

%{__chmod} a-x demos/*
%{__sed} -i -e '/^#!/,1d' demos/*

for i in %{_sourcedir}/*.pub; do
  install -Dpm644 $i tests/cert_support/$(basename $i)
done

%build
%py2_build
%py3_build

%install
%py2_install
%py3_install

%if %{with tests}
%check
# Remove sftp test
rm -f tests/test_sftp*.py
PYTHONPATH=%{buildroot}%{python2_sitelib} pytest-%{python2_version}
PYTHONPATH=%{buildroot}%{python3_sitelib} pytest-%{python3_version}
%endif

%files
%doc LICENSE
%doc README.rst
%{python2_sitelib}/%{module_name}-*.egg-info/
%{python2_sitelib}/%{module_name}/


%files -n python3-%{module_name}
%doc LICENSE
%doc README.rst
%{python3_sitelib}/%{module_name}-*.egg-info/
%{python3_sitelib}/%{module_name}/


%changelog
* Wed Aug 17 2022 TerryN <terryn94 at gmail.com> 2.7.2-1pclos2022
- update and rebuild for python 3.10
- add CVE-2022-24302 patch

* Fri Mar 29 2019 tex 2.4.2-1pclos2019
- new
